@@ -49,7 +49,6 @@
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_DATE_FORMAT_WIDGET "date_format_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_TEXT_WIDGET "preview_text_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_IMAGE_WIDGET "preview_image_combobox"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_SOUND_WIDGET "preview_sound_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_FOLDER_WIDGET "preview_folder_combobox"
 
 /* bool preferences */
@@ -189,7 +188,7 @@ preferences_show_help (GtkWindow *parent,
 	g_assert (helpfile != NULL);
 	g_assert (sect_id != NULL);
 
-	help_string = g_strdup_printf ("ghelp:%s#%s", helpfile, sect_id);
+	help_string = g_strdup_printf ("help:%s/%s", helpfile, sect_id);
 
 	gtk_show_uri (gtk_window_get_screen (parent),
 		      help_string, gtk_get_current_event_time (),
@@ -777,10 +776,6 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_IMAGE_WIDGET,
 			   NAUTILUS_PREFERENCES_SHOW_IMAGE_FILE_THUMBNAILS,
 			   (const char **) preview_values);
-	bind_builder_enum (builder, nautilus_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_SOUND_WIDGET,
-			   NAUTILUS_PREFERENCES_PREVIEW_SOUND,
-			   (const char **) preview_values);
 	bind_builder_enum (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_FOLDER_WIDGET,
 			   NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS,
